<?php
/**
 * VuFind Record Driver
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library, 2023.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Export
 * @author   JP Kanter <kanter@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
$ris_formats = [
  "Article" => "JOUR",
  "Atlas" => "BOOK",
  "Audiobook" => "SOUND",
  "AudioCassette" => "SOUND",
  "AudioDisc" => "SOUND",
  "AudioTapeReel" => "SOUND",
  "Autobiography" => "BOOK",
  "Bibliography" => "BOOK",
  "Biography" => "BOOK",
  "BluRayDisc" => "VIDEO",
  "Book" => "BOOK",
  "BookComponentPart" => "CHAP",
  "Card" => "CHART",
  "CartographicImage" => "MAP",
  "CartographicTactileThreeDimensionalForm" => "GEN",
  "CD" => "SOUND",
  "CDROM" => "COMP",
  "ComicBook" => "BOOK",
  "CommemorativePublication" => "BOOK",
  "ComputerChipCartridge" => "COMP",
  "ComputerData" => "COMP",
  "ComputerDataset" => "COMP",
  "ComputerDiscCartridge" => "COMP",
  "ComputerProgram" => "COMP",
  "ConferenceProceedings" => "CONF",
  "Database" => "DBASE",
  "Depositum" => "GEN",
  "DVD" => "VIDEO",
  "DVDAudio" => "SOUND",
  "DVDROM" => "COMP",
  "DVDVideo" => "VIDEO",
  "eBook" => "EBOOK",
  "ElectronicArticle" => "EJOUR",
  "ElectronicBook" => "EBOOK",
  "ElectronicBookComponentPart" => "ECHAP",
  "ElectronicBookPart" => "ECHAP",
  "ElectronicJournal" => "JFULL",
  "ElectronicManuscript" => "EBOOK",
  "ElectronicMusicRecording" => "SOUND",
  "ElectronicNewspaper" => "NEWS",
  "ElectronicProceeding" => "CONF",
  "ElectronicResourceRemoteAccess" => "WEB",
  "ElectronicSchoolPublication" => "GEN",
  "ElectronicSerial" => "JOUR",
  "ElectronicSerialComponentPart" => "EJOUR",
  "ElectronicThesis" => "THES",
  "ElectronicVisualMedia" => "ART",
  "EncyclopediaEntry" => "ART",
  "ExhibitionCatalogue" => "CTLG",
  "FilmCartridge" => "MPCT",
  "FilmReel" => "MPCT",
  "FilmRoll" => "MPCT",
  "Filmstrip" => "MPCT",
  "FlashCard" => "GEN",
  "FloppyDisc" => "COMP",
  "Forschungsdaten" => "DBASE",
  "IllustratedBook" => "BOOK",
  "Journal" => "JFULL",
  "Kit" => "GEN",
  "Kryptonachlass" => "GEN",
  "LooseLeafCollection" => "GEN",
  "Manuscript" => "BOOK",
  "ManuscriptFragement" => "GEN",
  "Map" => "MAP",
  "Microfiche" => "GEN",
  "MicrofilmReel" => "GEN",
  "MicrofilmRoll" => "GEN",
  "Mikroform" => "GEN",
  "MixedMaterials" => "GEN",
  "MonographSeries" => "GEN",
  "MusicalScore" => "MUSIC",
  "Nachlass" => "GEN",
  "Newspaper" => "NEWS",
  "NotatedMusic" => "MUSIC",
  "Object" => "GEN",
  "OnlineResource" => "WEB",
  "OtherAudioCarrier" => "SOUND",
  "OtherComputerCarrier" => "COMP",
  "OtherMicroformCarrier" => "GEN",
  "OtherVideoCarrier" => "VIDEO",
  "OverheadTransparency" => "SLIDE",
  "PerformedMusic" => "SOUND",
  "PersonalDocument" => "UNPB",
  "Photo" => "ART",
  "Preprint" => "JOUR",
  "Record" => "GEN",
  "ReliefPrint" => "GEN",
  "Sammlung" => "GEN",
  "Serial" => "SER",
  "SerialComponentPart" => "JOUR",
  "SerialPart" => "BOOK",
  "Sheet" => "GEN",
  "Slide" => "SLIDE",
  "Software" => "COMP",
  "Sounds" => "SOUND",
  "SpecialPrint" => "JOUR",
  "SpokenWord" => "SOUND",
  "StillImage" => "ART",
  "TactileText" => "GEN",
  "Teilarchiv" => "GEN",
  "Teilnachlass" => "GEN",
  "Teilsammlung" => "GEN",
  "Textbook" => "BOOK",
  "Thesis" => "THES",
  "ThreeDimensionalForm" => "GEN",
  "ThreeDimensionalMovingImage" => "GEN",
  "TwoDimensionalMovingImage" => "MPCT",
  "Unknown" => "GEN",
  "VHS" => "VIDEO",
  "Video" => "VIDEO",
  "VideoCassette" => "VIDEO",
  "VideoDisc" => "VIDEO",
  "VinylRecord" => "SOUND",
  "Volume" => "BOOK",
  "Vorlass" => "GEN",
  "Weblog" => "BLOG",
  "Website" => "WEB",
];

$bib_formats = [
  "Article" => "article",
  "Atlas" => "book",
  "Audiobook" => "misc",
  "AudioCassette" => "misc",
  "AudioDisc" => "misc",
  "AudioTapeReel" => "misc",
  "Autobiography" => "book",
  "Bibliography" => "book",
  "Biography" => "book",
  "BluRayDisc" => "misc",
  "Book" => "book",
  "BookComponentPart" => "incollection",
  "Card" => "misc",
  "CartographicImage" => "misc",
  "CartographicTactileThreeDimensionalForm" => "misc",
  "CD" => "misc",
  "CDROM" => "misc",
  "ComicBook" => "book",
  "CommemorativePublication" => "book",
  "ComputerChipCartridge" => "misc",
  "ComputerData" => "misc",
  "ComputerDataset" => "misc",
  "ComputerDiscCartridge" => "misc",
  "ComputerProgram" => "misc",
  "ConferenceProceedings" => "proceedings",
  "Database" => "misc",
  "Depositum" => "misc",
  "DVD" => "misc",
  "DVDAudio" => "misc",
  "DVDROM" => "misc",
  "DVDVideo" => "misc",
  "eBook" => "book",
  "ElectronicArticle" => "article",
  "ElectronicBook" => "book",
  "ElectronicBookComponentPart" => "incollection",
  "ElectronicBookPart" => "incollection",
  "ElectronicJournal" => "misc",
  "ElectronicManuscript" => "book",
  "ElectronicMusicRecording" => "misc",
  "ElectronicNewspaper" => "misc",
  "ElectronicProceeding" => "proceedings",
  "ElectronicResourceRemoteAccess" => "misc",
  "ElectronicSchoolPublication" => "misc",
  "ElectronicSerial" => "misc",
  "ElectronicSerialComponentPart" => "article",
  "ElectronicThesis" => "phdthesis",
  "ElectronicVisualMedia" => "misc",
  "EncyclopediaEntry" => "article",
  "ExhibitionCatalogue" => "misc",
  "FilmCartridge" => "misc",
  "FilmReel" => "misc",
  "FilmRoll" => "misc",
  "Filmstrip" => "misc",
  "FlashCard" => "misc",
  "FloppyDisc" => "misc",
  "Forschungsdaten" => "misc",
  "IllustratedBook" => "book",
  "Journal" => "misc",
  "Kit" => "misc",
  "Kryptonachlass" => "misc",
  "LooseLeafCollection" => "misc",
  "Manuscript" => "book",
  "ManuscriptFragement" => "misc",
  "Map" => "misc",
  "Microfiche" => "misc",
  "MicrofilmReel" => "misc",
  "MicrofilmRoll" => "misc",
  "Mikroform" => "misc",
  "MixedMaterials" => "misc",
  "MonographSeries" => "misc",
  "MusicalScore" => "misc",
  "Nachlass" => "misc",
  "Newspaper" => "misc",
  "NotatedMusic" => "misc",
  "Object" => "misc",
  "OnlineResource" => "misc",
  "OtherAudioCarrier" => "misc",
  "OtherComputerCarrier" => "misc",
  "OtherMicroformCarrier" => "misc",
  "OtherVideoCarrier" => "misc",
  "OverheadTransparency" => "misc",
  "PerformedMusic" => "misc",
  "PersonalDocument" => "misc",
  "Photo" => "misc",
  "Preprint" => "article",
  "Record" => "misc",
  "ReliefPrint" => "misc",
  "Sammlung" => "misc",
  "Serial" => "misc",
  "SerialComponentPart" => "article",
  "SerialPart" => "book",
  "Sheet" => "misc",
  "Slide" => "misc",
  "Software" => "misc",
  "Sounds" => "misc",
  "SpecialPrint" => "article",
  "SpokenWord" => "misc",
  "StillImage" => "misc",
  "TactileText" => "misc",
  "Teilarchiv" => "misc",
  "Teilnachlass" => "misc",
  "Teilsammlung" => "misc",
  "Textbook" => "book",
  "Thesis" => "phdthesis",
  "ThreeDimensionalForm" => "misc",
  "ThreeDimensionalMovingImage" => "misc",
  "TwoDimensionalMovingImage" => "misc",
  "Unknown" => "misc",
  "VHS" => "misc",
  "Video" => "misc",
  "VideoCassette" => "misc",
  "VideoDisc" => "misc",
  "VinylRecord" => "misc",
  "Volume" => "book",
  "Vorlass" => "misc",
  "Weblog" => "misc",
  "Website" => "misc",
  "WorkingManuscripts" => "misc",
];
?>